@@ -1,4 +1,3 @@
-import datetime
 import hashlib
 import json
 import logging
@@ -18,6 +17,12 @@ LOG = logging.getLogger(__name__)
 register = django.template.Library()
 
 
+@register.filter
+def mbd_sorted(iterable):
+    """Just do (python) sorting -- useful for models that use custom python ordering"""
+    return sorted(iterable)
+
+
 @register.simple_tag(takes_context=True)
 def mbd_menu_active(context, name):
     return "mbd-menu-active" if context["request"].path == config.URIS[name]["view"].uri else ""
@@ -37,7 +42,7 @@ def mbd_dict_get(dict_, key, default=None):
 
 @register.filter
 def mbd_fromtimestamp(stamp):
-    return datetime.datetime.fromtimestamp(stamp)
+    return util.Datetime.from_stamp(stamp)
 
 
 @register.filter
@@ -117,14 +122,8 @@ def mbd_absolute_uri(context, location):
     return context.get("request").build_absolute_uri(location)
 
 
-@register.simple_tag(takes_context=True)
-def mbd_next(context):
-    request = context.get("request")
-    return request.get_full_path() if request.GET.get("output") != "html-snippet" else request.META.get("HTTP_REFERER")
-
-
 @register.inclusion_tag("mini_buildd/includes/tags/api.html", takes_context=True)
-def mbd_api(context, call, name=None, hide_options=False, verbose=False, **kwargs):
+def mbd_api(context, call, name=None, hide_options=False, verbose=False, popup=True, **kwargs):
     prefix = "value_"
     api_args = {k[len(prefix):]: v for k, v in kwargs.items() if k.startswith(prefix)}
     if isinstance(call, str):
@@ -148,6 +147,7 @@ def mbd_api(context, call, name=None, hide_options=False, verbose=False, **kwarg
         "name": api_call.name if name is None else name,
         "is_authorized": api_call.AUTH.is_authorized(context.get("user")),
         "verbose": verbose,
+        "popup": popup,
     }
 
 
@@ -247,6 +247,8 @@ class PlainFilter(dict):
         self["toc"] = []  # May be filled by filters (table of contents)
 
         if file_path is not None and os.path.exists(file_path):
+            self["mtime"] = os.path.getmtime(file_path)
+
             dummy_, extension = os.path.splitext(file_path)
             self["extension"] = extension[1:]
 
